==============
atsphinx-typst
==============


.. note:: This is ALPHA-stage product.

    We implement basic features to work for us,
    but you may encounter missing features or malfunctions when using it.

Quickstart
==========

1. Add ``atsphinx-typst[pdf]`` into your project as documentation dependencies.
2. Run ``make typstpdf`` on your document.
3. You can open ``typstpdf/document.pdf`` on your document's build directory.

Refs
====

- `Typst reference <https://typst.app/docs/reference/>`_.

.. toctree::
   :maxdepth: 1

   overview
   usage/index
   changes
